import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { timeout, catchError } from 'rxjs/operators';
import { Logger, NgLoggerModule, Level } from '@nsalaun/ng-logger';
import { TimeoutError } from 'rxjs';
import { ErrorObservable } from 'rxjs/observable/ErrorObservable';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Config {
}
const EASYDMS_CONFIG = new InjectionToken('easydms.config');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasydmsService {
    /**
     * @param {?} http
     * @param {?} logger
     * @param {?} config
     */
    constructor(http, logger, config) {
        this.http = http;
        this.logger = logger;
        this.config = config;
    }
    /**
     * 接口服务器地址getter
     * @return {?}
     */
    get apiEndPoint() {
        return this.config.apiEndPoint;
    }
    /**
     * @return {?}
     */
    get timeout() {
        return this.config.timeout || 5000;
    }
    /**
     * @return {?}
     */
    get path() {
        return this.config.path || 'easydms';
    }
    /**
     * 摄像头分类及列表获取接口
     * @param {?} __0
     * @return {?}
     */
    getCusAreaInfo({ caCard, areaId, curPage = 1, pageSize = 10 }) {
        let /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/user/getCusAreaInfo?caCard=${caCard}&curPage=${curPage}&pageSize=${pageSize}`;
        if (areaId) {
            url += `&areaId=${areaId}`;
        }
        this.logger.debug(`${EasydmsService.TAG} getCusAreaInfo() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError((err) => {
            return this.handleError(err, 'getCusAreaInfo');
        }));
    }
    /**
     * @param {?} __0
     * @return {?}
     */
    getCustomerIPCArea({ caCard, curPage = 1, pageSize = 10 }) {
        let /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/inf/getCustomerIPCArea?caCard=${caCard}&curPage=${curPage}&pageSize=${pageSize}`;
        this.logger.debug(`${EasydmsService.TAG} getCustomerIPCArea() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError((err) => {
            return this.handleError(err, 'getCustomerIPCArea');
        }));
    }
    /**
     * @param {?} __0
     * @return {?}
     */
    getCustomerIPCRel({ caCard }) {
        let /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/inf/getCustomerIPCRel?caCard=${caCard}`;
        this.logger.debug(`${EasydmsService.TAG} getCustomerIPCRel() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError((err) => {
            return this.handleError(err, 'getCustomerIPCRel');
        }));
    }
    /**
     * @param {?} __0
     * @return {?}
     */
    getCustomerIPCRelByArea({ caCard, curPage = 1, pageSize = 10, FRegionCode }) {
        let /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/inf/getCustomerIPCRelByArea?caCard=${caCard}&curPage=${curPage}&pageSize=${pageSize}&FRegionCode=${FRegionCode}`;
        this.logger.debug(`${EasydmsService.TAG} getCustomerIPCRelByArea() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError((err) => {
            return this.handleError(err, 'getCustomerIPCRelByArea');
        }));
    }
    /**
     * DMS接口
     * 获取监控回看列表
     * @param {?} region
     * @param {?} apiPath 接口完整地址，如：http://172.20.79.3/huikan/interface/DMSdata.php
     * @return {?}
     */
    getReviewIpcList(region, apiPath) {
        const /** @type {?} */ data = `{"region":"${region}"}`;
        const /** @type {?} */ url = `${apiPath}?mod="ipc"&action="apiRegionGetIPCS"&data=${encodeURIComponent(data)}`;
        this.logger.debug(`${EasydmsService.TAG} getReviewIpcList() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError((err) => {
            return this.handleError(err, 'getReviewIpcList');
        }));
    }
    /**
     * DMS接口
     * 获取监控摄像头下对应时间的回看视频
     * @param {?} guid
     * @param {?} start
     * @param {?} end
     * @param {?} apiPath 接口完整地址，如：http://172.20.79.3/huikan/interface/DMSdata.php
     * @return {?}
     */
    getReviewPlayList(guid, start, end, apiPath) {
        const /** @type {?} */ data = `{"guid":"${guid}","start":"${start}","end":"${end}"}`;
        const /** @type {?} */ url = `${apiPath}?mod="ipc"&action="apiIpcGetReviewPlayList"&data=${encodeURIComponent(data)}`;
        this.logger.debug(`${EasydmsService.TAG} getReviewPlayList() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError((err) => {
            return this.handleError(err, 'getReviewPlayList');
        }));
    }
    /**
     * 用户登录接口
     * @param {?} __0
     * @return {?}
     */
    userconfirmAPP({ logid, password, deviceid }) {
        let /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/APP/checkuser/userconfirmAPP?logid=${logid}&password=${password}`;
        if (deviceid) {
            url += `&deviceid=${deviceid}`;
        }
        this.logger.debug(`${EasydmsService.TAG} userconfirmAPP() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(err => {
            return this.handleError(err, 'userconfirmAPP');
        }));
    }
    /**
     * 用户免登陆确认
     * @param {?} __0
     * @return {?}
     */
    freeconfirmAPP({ deviceid, token }) {
        const /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/APP/freeconfirm/freeconfirmAPP?deviceid=${deviceid}&token=${token}`;
        this.logger.debug(`${EasydmsService.TAG} freeconfirmAPP() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(err => {
            return this.handleError(err, 'freeconfirmAPP');
        }));
    }
    /**
     * 修改密码信息
     * @param {?} logid
     * @param {?} token
     * @param {?} password
     * @param {?} oldPassword
     * @return {?}
     */
    updatePassword(logid, token, password, oldPassword) {
        const /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/APP/checkuser/updatePassword?logid=${logid}&token=${token}&password=${password}&oldPassword=${oldPassword}`;
        this.logger.debug(`${EasydmsService.TAG} updatePassword() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(err => {
            return this.handleError(err, 'updatePassword');
        }));
    }
    /**
     * 注册用户
     * @param {?} logid
     * @param {?} name
     * @param {?} certificateid
     * @param {?} mobile
     * @param {?} address
     * @param {?} password
     * @param {?} email
     * @param {?} sex
     * @return {?}
     */
    addAPP(logid, name, certificateid, mobile, address, password, email, sex) {
        const /** @type {?} */ url = `${this.apiEndPoint}/${this.path}/APP/checkuser/addAPP?logid=${logid}&name=${name}&certificateid=${certificateid}&type=1&mobile=${mobile}&address=${address}&password=${password}&email=${email}&sex=${sex}`;
        this.logger.debug(`${EasydmsService.TAG} addAPP() request url is ${url}`);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(err => {
            return this.handleError(err, 'addAPP');
        }));
    }
    /**
     * 错误处理
     * @param {?} error
     * @param {?} type
     * @return {?}
     */
    handleError(error, type) {
        let /** @type {?} */ message, /** @type {?} */ status;
        if (error.error instanceof ErrorEvent) {
            // A client-side or network error occurred. Handle it accordingly.
            message = '没有网络连接，请检查网络设置';
            status = 'disconnect';
        }
        else if (error instanceof TimeoutError) {
            message = '网络连接超时';
            status = 'timeout';
        }
        else {
            // The backend returned an unsuccessful response code.
            // The response body may contain clues as to what went wrong,
            status = 'error';
            if (error.status == 0) {
                message = '没有网络连接，请检查网络设置';
            }
            else {
                message = `服务端报错:${error.message}`;
            }
        }
        this.logger.error(`${EasydmsService.TAG} execute method ${type} error: ${JSON.stringify(error)}`);
        // return an ErrorObservable with a user-facing error message
        return new ErrorObservable({
            message: message,
            type: type,
            status: status
        });
    }
}
EasydmsService.TAG = '@evm-angular/easydms EasydmsService ';
EasydmsService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EasydmsService.ctorParameters = () => [
    { type: HttpClient, },
    { type: Logger, },
    { type: Config, decorators: [{ type: Inject, args: [EASYDMS_CONFIG,] },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasydmsModule {
    /**
     * @param {?=} config
     * @return {?}
     */
    static forRoot(config) {
        return {
            ngModule: EasydmsModule,
            providers: [
                EasydmsService,
                {
                    provide: EASYDMS_CONFIG, useValue: config
                }
            ]
        };
    }
}
EasydmsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    HttpClientModule,
                    NgLoggerModule.forRoot(Level.LOG)
                ]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { EasydmsModule, EasydmsService, Config as ɵa, EASYDMS_CONFIG as ɵb };
//# sourceMappingURL=evm-angular-easydms.js.map
