import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { timeout, catchError } from 'rxjs/operators';
import { Logger, NgLoggerModule, Level } from '@nsalaun/ng-logger';
import { TimeoutError } from 'rxjs';
import { ErrorObservable } from 'rxjs/observable/ErrorObservable';
import { CommonModule } from '@angular/common';

var Config = /** @class */ (function () {
    function Config() {
    }
    return Config;
}());
var EASYDMS_CONFIG = new InjectionToken('easydms.config');
var EasydmsService = /** @class */ (function () {
    function EasydmsService(http, logger, config) {
        this.http = http;
        this.logger = logger;
        this.config = config;
    }
    Object.defineProperty(EasydmsService.prototype, "apiEndPoint", {
        get: function () {
            return this.config.apiEndPoint;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EasydmsService.prototype, "timeout", {
        get: function () {
            return this.config.timeout || 5000;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EasydmsService.prototype, "path", {
        get: function () {
            return this.config.path || 'easydms';
        },
        enumerable: true,
        configurable: true
    });
    EasydmsService.prototype.getCusAreaInfo = function (_a) {
        var _this = this;
        var caCard = _a.caCard, areaId = _a.areaId, _b = _a.curPage, curPage = _b === void 0 ? 1 : _b, _c = _a.pageSize, pageSize = _c === void 0 ? 10 : _c;
        var url = this.apiEndPoint + "/" + this.path + "/user/getCusAreaInfo?caCard=" + caCard + "&curPage=" + curPage + "&pageSize=" + pageSize;
        if (areaId) {
            url += "&areaId=" + areaId;
        }
        this.logger.debug(EasydmsService.TAG + " getCusAreaInfo() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'getCusAreaInfo');
        }));
    };
    EasydmsService.prototype.getCustomerIPCArea = function (_a) {
        var _this = this;
        var caCard = _a.caCard, _b = _a.curPage, curPage = _b === void 0 ? 1 : _b, _c = _a.pageSize, pageSize = _c === void 0 ? 10 : _c;
        var url = this.apiEndPoint + "/" + this.path + "/inf/getCustomerIPCArea?caCard=" + caCard + "&curPage=" + curPage + "&pageSize=" + pageSize;
        this.logger.debug(EasydmsService.TAG + " getCustomerIPCArea() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'getCustomerIPCArea');
        }));
    };
    EasydmsService.prototype.getCustomerIPCRel = function (_a) {
        var _this = this;
        var caCard = _a.caCard;
        var url = this.apiEndPoint + "/" + this.path + "/inf/getCustomerIPCRel?caCard=" + caCard;
        this.logger.debug(EasydmsService.TAG + " getCustomerIPCRel() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'getCustomerIPCRel');
        }));
    };
    EasydmsService.prototype.getCustomerIPCRelByArea = function (_a) {
        var _this = this;
        var caCard = _a.caCard, _b = _a.curPage, curPage = _b === void 0 ? 1 : _b, _c = _a.pageSize, pageSize = _c === void 0 ? 10 : _c, FRegionCode = _a.FRegionCode;
        var url = this.apiEndPoint + "/" + this.path + "/inf/getCustomerIPCRelByArea?caCard=" + caCard + "&curPage=" + curPage + "&pageSize=" + pageSize + "&FRegionCode=" + FRegionCode;
        this.logger.debug(EasydmsService.TAG + " getCustomerIPCRelByArea() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'getCustomerIPCRelByArea');
        }));
    };
    EasydmsService.prototype.getReviewIpcList = function (region, apiPath) {
        var _this = this;
        var data = "{\"region\":\"" + region + "\"}";
        var url = apiPath + "?mod=\"ipc\"&action=\"apiRegionGetIPCS\"&data=" + encodeURIComponent(data);
        this.logger.debug(EasydmsService.TAG + " getReviewIpcList() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'getReviewIpcList');
        }));
    };
    EasydmsService.prototype.getReviewPlayList = function (guid, start, end, apiPath) {
        var _this = this;
        var data = "{\"guid\":\"" + guid + "\",\"start\":\"" + start + "\",\"end\":\"" + end + "\"}";
        var url = apiPath + "?mod=\"ipc\"&action=\"apiIpcGetReviewPlayList\"&data=" + encodeURIComponent(data);
        this.logger.debug(EasydmsService.TAG + " getReviewPlayList() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'getReviewPlayList');
        }));
    };
    EasydmsService.prototype.userconfirmAPP = function (_a) {
        var _this = this;
        var logid = _a.logid, password = _a.password, deviceid = _a.deviceid;
        var url = this.apiEndPoint + "/" + this.path + "/APP/checkuser/userconfirmAPP?logid=" + logid + "&password=" + password;
        if (deviceid) {
            url += "&deviceid=" + deviceid;
        }
        this.logger.debug(EasydmsService.TAG + " userconfirmAPP() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'userconfirmAPP');
        }));
    };
    EasydmsService.prototype.freeconfirmAPP = function (_a) {
        var _this = this;
        var deviceid = _a.deviceid, token = _a.token;
        var url = this.apiEndPoint + "/" + this.path + "/APP/freeconfirm/freeconfirmAPP?deviceid=" + deviceid + "&token=" + token;
        this.logger.debug(EasydmsService.TAG + " freeconfirmAPP() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'freeconfirmAPP');
        }));
    };
    EasydmsService.prototype.updatePassword = function (logid, token, password, oldPassword) {
        var _this = this;
        var url = this.apiEndPoint + "/" + this.path + "/APP/checkuser/updatePassword?logid=" + logid + "&token=" + token + "&password=" + password + "&oldPassword=" + oldPassword;
        this.logger.debug(EasydmsService.TAG + " updatePassword() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'updatePassword');
        }));
    };
    EasydmsService.prototype.addAPP = function (logid, name, certificateid, mobile, address, password, email, sex) {
        var _this = this;
        var url = this.apiEndPoint + "/" + this.path + "/APP/checkuser/addAPP?logid=" + logid + "&name=" + name + "&certificateid=" + certificateid + "&type=1&mobile=" + mobile + "&address=" + address + "&password=" + password + "&email=" + email + "&sex=" + sex;
        this.logger.debug(EasydmsService.TAG + " addAPP() request url is " + url);
        return this.http.get(url)
            .pipe(timeout(this.timeout), catchError(function (err) {
            return _this.handleError(err, 'addAPP');
        }));
    };
    EasydmsService.prototype.handleError = function (error, type) {
        var message, status;
        if (error.error instanceof ErrorEvent) {
            message = '没有网络连接，请检查网络设置';
            status = 'disconnect';
        }
        else if (error instanceof TimeoutError) {
            message = '网络连接超时';
            status = 'timeout';
        }
        else {
            status = 'error';
            if (error.status == 0) {
                message = '没有网络连接，请检查网络设置';
            }
            else {
                message = "\u670D\u52A1\u7AEF\u62A5\u9519:" + error.message;
            }
        }
        this.logger.error(EasydmsService.TAG + " execute method " + type + " error: " + JSON.stringify(error));
        return new ErrorObservable({
            message: message,
            type: type,
            status: status
        });
    };
    return EasydmsService;
}());
EasydmsService.TAG = '@evm-angular/easydms EasydmsService ';
EasydmsService.decorators = [
    { type: Injectable },
];
EasydmsService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: Logger, },
    { type: Config, decorators: [{ type: Inject, args: [EASYDMS_CONFIG,] },] },
]; };
var EasydmsModule = /** @class */ (function () {
    function EasydmsModule() {
    }
    EasydmsModule.forRoot = function (config) {
        return {
            ngModule: EasydmsModule,
            providers: [
                EasydmsService,
                {
                    provide: EASYDMS_CONFIG, useValue: config
                }
            ]
        };
    };
    return EasydmsModule;
}());
EasydmsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    HttpClientModule,
                    NgLoggerModule.forRoot(Level.LOG)
                ]
            },] },
];

export { EasydmsModule, EasydmsService, Config as ɵa, EASYDMS_CONFIG as ɵb };
//# sourceMappingURL=evm-angular-easydms.js.map
