import { HttpClient } from '@angular/common/http';
import { Config } from '../../config';
import { Logger } from '@nsalaun/ng-logger';
import { Observable } from 'rxjs';
export declare class EasydmsService {
    private http;
    private logger;
    private config;
    private static TAG;
    constructor(http: HttpClient, logger: Logger, config: Config);
    /**
     * 接口服务器地址getter
     */
    readonly apiEndPoint: string;
    readonly timeout: number;
    readonly path: string;
    /**
     * 摄像头分类及列表获取接口
     * @param params.caCard CA卡号或登录账户
     * @param [params.areaId] 区域id
     * @param [params.curPage] 当前页码
     * @param [params.pageSize] 每页显示数量
     */
    getCusAreaInfo({caCard, areaId, curPage, pageSize}: {
        caCard: string;
        areaId?: string;
        curPage?: number;
        pageSize?: number;
    }): Observable<any>;
    getCustomerIPCArea({caCard, curPage, pageSize}: {
        caCard: string;
        curPage?: number;
        pageSize?: number;
    }): Observable<any>;
    getCustomerIPCRel({caCard}: {
        caCard: string;
    }): Observable<any>;
    getCustomerIPCRelByArea({caCard, curPage, pageSize, FRegionCode}: {
        caCard: string;
        curPage?: number;
        pageSize?: number;
        FRegionCode: string;
    }): Observable<any>;
    /**
     * DMS接口
     * 获取监控回看列表
     * @param region
     * @param apiPath 接口完整地址，如：http://172.20.79.3/huikan/interface/DMSdata.php
     */
    getReviewIpcList(region: string, apiPath: string): Observable<any>;
    /**
     * DMS接口
     * 获取监控摄像头下对应时间的回看视频
     * @param guid
     * @param start
     * @param end
     * @param apiPath 接口完整地址，如：http://172.20.79.3/huikan/interface/DMSdata.php
     */
    getReviewPlayList(guid: string, start: string, end: string, apiPath: string): Observable<any>;
    /**
     * 用户登录接口
     * @param params.logid
     * @param params.password
     * @param params.deviceid
     */
    userconfirmAPP({logid, password, deviceid}: {
        logid: string;
        password: string;
        deviceid?: string;
    }): Observable<any>;
    /**
     * 用户免登陆确认
     */
    freeconfirmAPP({deviceid, token}: {
        deviceid: string;
        token: string;
    }): Observable<any>;
    /**
     * 修改密码信息
     */
    updatePassword(logid: string, token: string, password: string, oldPassword: string): Observable<any>;
    /**
     * 注册用户
     */
    addAPP(logid: string, name: string, certificateid: string, mobile: string, address: string, password: string, email: string, sex: string): Observable<any>;
    /**
     * 错误处理
     */
    private handleError(error, type);
}
